Class: Generators::R2DOCGenerator
- Inherits:
-
HTMLGenerator
- Object
- HTMLGenerator
- Generators::R2DOCGenerator
- Includes:
- ERB::Util, R2Doc::Generator, R2Doc::TemplateUtil
- Defined in:
- lib/rdoc/generators/r2doc_generator.rb
Overview
R2Doc generator for RDoc v1.0.1
Class Method Summary collapse
-
.for(options) ⇒ Object
Factory method.
Instance Method Summary collapse
-
#complete_method_list ⇒ Object
Return a list of all defined methods.
-
#create_class_context(context, file, options) ⇒ Object
Create a new class object for this RDoc version.
-
#create_file_context(context, options) ⇒ Object
Create a new file object for this RDoc version.
-
#generate_prep ⇒ Object
Perform version-specific initialization.
-
#get_toplevels ⇒ Object
Return the list of top level objects for this RDoc version.
-
#initialize(*args) ⇒ R2DOCGenerator
constructor
Constructor.
-
#template_name ⇒ Object
Return the name of the template.
Methods included from R2Doc::Generator
Methods included from R2Doc::TemplateUtil
#content_tag, gen_url, #link_to, #path_to, #render_partial, #stripe_class
Methods inherited from HTMLGenerator
Constructor Details
#initialize(*args) ⇒ R2DOCGenerator
Constructor
69 70 71 72 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 69 def initialize(*args) super build_static_file_list end |
Class Method Details
.for(options) ⇒ Object
Factory method
64 65 66 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 64 def R2DOCGenerator.for() R2DOCGenerator.new() end |
Instance Method Details
#complete_method_list ⇒ Object
Return a list of all defined methods
99 100 101 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 99 def complete_method_list HtmlMethod.all_methods end |
#create_class_context(context, file, options) ⇒ Object
Create a new class object for this RDoc version
94 95 96 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 94 def create_class_context(context, file, ) HtmlClass.new(context, file, CLASS_DIR, ) end |
#create_file_context(context, options) ⇒ Object
Create a new file object for this RDoc version
89 90 91 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 89 def create_file_context(context, ) HtmlFile.new(context, , FILE_DIR) end |
#generate_prep ⇒ Object
Perform version-specific initialization
75 76 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 75 def generate_prep end |
#get_toplevels ⇒ Object
Return the list of top level objects for this RDoc version
84 85 86 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 84 def get_toplevels RDoc::TopLevel end |
#template_name ⇒ Object
Return the name of the template
79 80 81 |
# File 'lib/rdoc/generators/r2doc_generator.rb', line 79 def template_name .template || 'r2doc' end |