Module: R2Doc::MethodExtensions
- Defined in:
- lib/r2doc/context_extensions.rb
Overview
Extensions for the RDoc::Generator::Method / Generators::HtmlMethod class
Instance Method Summary collapse
-
#is_method_context? ⇒ Boolean
Returns true if this object is a method context.
Instance Method Details
#is_method_context? ⇒ Boolean
Returns true if this object is a method context
232 233 234 |
# File 'lib/r2doc/context_extensions.rb', line 232 def is_method_context? true end |